@@ -1,5 +1,6 @@
 """Default tile layout. Similar to DWM's default."""
 from s3wm.layouts.default_tile.key_bindings import (
+    change_gaps,
     change_tab,
     kill_focused_window,
     move_focus,
@@ -13,4 +14,5 @@ __all__ = [
     "move_focus",
     "move_window_to_tab",
     "change_tab",
+    "change_gaps",
 ]
